PathMatcherBuilder typedef
PathMatcherBuilder =
PathMatcher Function()
A factory function that creates an instance of a PathMatcher.
This allows for different path matching strategies to be provided or configured. Returns a PathMatcher instance.
Implementation
typedef PathMatcherBuilder = PathMatcher Function();